[totem] backend: Rename BvwRotation member to R_ZERO
- From: Bastien Nocera <hadess src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [totem] backend: Rename BvwRotation member to R_ZERO
- Date: Wed, 27 Jun 2012 22:22:18 +0000 (UTC)
commit 947781384bb95d1ff4bf6b93a10a9be7b7015504
Author: Bastien Nocera <hadess hadess net>
Date: Wed Jun 27 23:20:26 2012 +0100
backend: Rename BvwRotation member to R_ZERO
To avoid too short nicknames when used in GSettings.
src/backend/bacon-video-widget-gst-0.10.c | 2 +-
src/backend/bacon-video-widget.h | 16 ++++++++--------
2 files changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/src/backend/bacon-video-widget-gst-0.10.c b/src/backend/bacon-video-widget-gst-0.10.c
index 61ef78b..24363e3 100644
--- a/src/backend/bacon-video-widget-gst-0.10.c
+++ b/src/backend/bacon-video-widget-gst-0.10.c
@@ -4874,7 +4874,7 @@ bacon_video_widget_set_rotation (BaconVideoWidget *bvw,
BvwRotation
bacon_video_widget_get_rotation (BaconVideoWidget *bvw)
{
- g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), BVW_ROTATION_R_0);
+ g_return_val_if_fail (BACON_IS_VIDEO_WIDGET (bvw), BVW_ROTATION_R_ZERO);
return bvw->priv->rotation;
}
diff --git a/src/backend/bacon-video-widget.h b/src/backend/bacon-video-widget.h
index 9c82a75..252a919 100644
--- a/src/backend/bacon-video-widget.h
+++ b/src/backend/bacon-video-widget.h
@@ -349,19 +349,19 @@ typedef enum {
/**
* BvwRotation:
* @BVW_ROTATION_0: No rotation
* @BVW_ROTATION_90R: Rotate 90 degrees to the right
* @BVW_ROTATION_180: Rotate 180 degrees
* @BVW_ROTATION_90L: Rotate 90 degrees to the left
*
* The rotation is used by the video widget, as set by
* bacon_video_widget_set_rotation().
**/
typedef enum {
- BVW_ROTATION_R_0 = 0,
- BVW_ROTATION_R_90R = 1,
- BVW_ROTATION_R_180 = 2,
- BVW_ROTATION_R_90L = 3
+ BVW_ROTATION_R_ZERO = 0,
+ BVW_ROTATION_R_90R = 1,
+ BVW_ROTATION_R_180 = 2,
+ BVW_ROTATION_R_90L = 3
} BvwRotation;
void bacon_video_widget_set_deinterlacing (BaconVideoWidget *bvw,
[
@@ -349,19 +349,19 @@ typedef enum {
/**
* BvwRotation:
- * @BVW_ROTATION_0: No rotation
- * @BVW_ROTATION_90R: Rotate 90 degrees to the right
- * @BVW_ROTATION_180: Rotate 180 degrees
- * @BVW_ROTATION_90L: Rotate 90 degrees to the left
+ * @BVW_ROTATION_R_ZERO: No rotation
+ * @BVW_ROTATION_R_90R: Rotate 90 degrees to the right
+ * @BVW_ROTATION_R_180: Rotate 180 degrees
+ * @BVW_ROTATION_R_90L: Rotate 90 degrees to the left
*
* The rotation is used by the video widget, as set by
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]